@@ -32,10 +32,10 @@ class DivisionsClient(DBClientMixin, CodeSeekingClientMixin, NestedClient):
         language: str,
         fallback_languages: Sequence[str] = []
     ) -> Sequence[DivisionDTO]:
-        query = DivisionTranslation.objects.filter(entity_ids=ids)
+        query = DivisionTranslation.objects.filter(entity_id__in=ids)
 
         if fallback_languages:
-            query = query.by_language_order([language] + fallback_languages)
+            query = query.by_language_order(*[language] + fallback_languages)
         else:
             query = query.by_language(language)
 
