@@ -13,5 +13,5 @@ class DBClientMixin:
     model: Type[Model]
 
     _qs: QuerySet = cached_property(
-        lambda self: self.model.objects.using(self.settings.DB_NAME)
+        lambda self: self.model.objects.using(self.root.settings.DB_NAME)
     )
