@@ -1,7 +1,7 @@
 from wcd_geo_db.modules.code_seeker import CodeSeeker
 
-from .const import CODE
+from .const import SOURCE
 
 __all__ = 'KOATUU_SEEKER',
 
-KOATUU_SEEKER = CodeSeeker(CODE)
+KOATUU_SEEKER = CodeSeeker(name=SOURCE)
